import { NodePath, types, template } from '@babel/core';

/**
 * Processes CSS function calls in the AST, extracts styles defined as JavaScript objects,
 * and replaces them with hashed classNames.
 *
 *  @example
 * // Before
 * const text = css({ color: 'red'})
 * // After
 * const text = 'hashed_class_name';
 *
 * @param {NodePath<types.Program>} nodePath - The current node in the AST being traversed.
 * @param {typeof t} t - Babel types.
 * @param {template} template - Babel template function.
 * @param {Record<string, string>} importedStyleFunctions - An object containing the imported styled functions.
 */
declare function processCSS(nodePath: NodePath<types.Program>, t: typeof types, template: typeof template, importedStyleFunctions: Record<string, string>): void;

export { processCSS };
