import { NodePath, types } from '@babel/core';

/**
 * Processes the JSXElement nodes in the AST and replaces the 'k' syntax from '@kuma-ui/core'
 * with corresponding 'Box' component. This allows usage of the 'k' syntax as a shorthand for creating
 * styled components, e.g. <k.div> is transformed to <Box as="div">.
 *
 * @param {NodePath<types.Program>} node - The NodePath object representing the Program node.
 * @param {typeof types} t - The Babel types object.
 * @param {Record<string, string>} importedStyleFunctions - An object containing the imported styled functions.
 */
declare const replaceKwithBox: (node: NodePath<types.Program>, t: typeof types, importedStyleFunctions: Record<string, string>) => void;

export { replaceKwithBox };
